package zero1hd.rhythmbullet.ui.windows;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.math.Vector2;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.List;
import com.badlogic.gdx.scenes.scene2d.ui.ScrollPane;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Slider;
import com.badlogic.gdx.scenes.scene2d.ui.Window;

import zero1hd.rhythmbullet.entity.EntityManager;
import zero1hd.rhythmbullet.entity.EntityIndex;
import zero1hd.rhythmbullet.entity.ally.Laser;
import zero1hd.rhythmbullet.entity.enemies.Bar;
import zero1hd.rhythmbullet.entity.enemies.Flake;
import zero1hd.rhythmbullet.entity.enemies.Pellet;
import zero1hd.rhythmbullet.entity.enemies.Shard;
import zero1hd.rhythmbullet.entity.enemies.VoidCircle;

public class SpawnerWindow extends Window {
	private EntityManager ec;
	private Stage stage;
	
	private List<EntityIndex> listOfEntities;
	private ScrollPane scroller;
	
	private Slider mod1;
	private Slider mod2;
	private Slider mod3;
	private Slider mod4;
	
	public SpawnerWindow(String title, Skin skin, EntityManager ec, Stage stageForEntities) {
		super(title, skin, "tinted");
		this.ec = ec;
		stage = stageForEntities;
		
		mod1 = new Slider(0.1f, 50f, 0.01f, true, skin);
		mod2 = new Slider(0f, 15f, 0.01f, true, skin);
		mod3 = new Slider(0.1f, 15f, 0.01f, true, skin);
		mod4 = new Slider(1f, 12f, 0.01f, true, skin);
		
		listOfEntities = new List<>(skin);
		listOfEntities.setItems(EntityIndex.values());
		
		scroller = new ScrollPane(listOfEntities);
		add(scroller).expandY().fillY().spaceRight(15f);
		
		add(mod1, mod2, mod3, mod4);
		
		setSize(300f, 375f);
	}
	
	
	@Override
	public boolean remove() {
		return super.remove();
	}
	
	private Vector2 coords = new Vector2();
	@Override
	public void act(float delta) {
		if (Gdx.input.justTouched() && Gdx.input.isKeyPressed(Keys.CONTROL_LEFT)) {
			coords.set(Gdx.input.getX(), Gdx.input.getY());
			stage.screenToStageCoordinates(coords);
			

			switch(listOfEntities.getSelected()) {
			case LASER:
				Laser laser = ec.laser.buildEntity();
				laser.init(coords.x, coords.y, mod1.getValue());
				stage.addActor(laser);
				break;
			case PELLET:
				Pellet pellet = ec.pellet.buildEntity();
				pellet.init(coords.x, coords.y, mod2.getValue()/mod2.getMaxValue()*360f, mod1.getValue());
				stage.addActor(pellet);
				break;
			case VOID_CIRCLE:
				VoidCircle voidCircle = ec.voidCircle.buildEntity();
				voidCircle.init(mod2.getValue(), coords.x, coords.y, mod1.getValue(), mod3.getValue());
				stage.addActor(voidCircle);
				break;
			case SHARD:
				Shard shard = ec.shard.buildEntity();
				shard.init(coords.x, coords.y, mod2.getValue()/mod2.getMaxValue()*360f, mod1.getValue(), (int) mod3.getValue());
				stage.addActor(shard);
				break;
			case BAR:
				Bar bar = ec.bar.buildEntity();
				bar.init(coords.x, mod1.getValue());
				stage.addActor(bar);
				break;
			case FLAKE:
				Flake flake = ec.flake.buildEntity();
				flake.init(coords.x, coords.y, mod1.getValue(), mod3.getValue(), mod2.getValue()/mod2.getMaxValue()*360f, (int) mod4.getValue());
				stage.addActor(flake);
			default:
				break;
			}
		}
		super.act(delta);
	}
}
